/* ------------------------------------------------------------------------------
    I N T K - T H E M E
--------------------------------------------------------------------------------- */

/* FONTS */
@import url('//fonts.googleapis.com/css?family=Montserrat');
@import url('//fonts.googleapis.com/css?family=Lato:300');

.no-space {
    margin-left: 0px !important;
}

#FooterPortlet .managePortletsLink {
    display: none;
}

.folder_contents_portlet_manager .managePortletsLink {
    display: none;
}

#visual-portal-wrapper {
    width: 100%;
    margin-left: 0;
    margin-right: 0;
    padding-left: 0;
    padding-right: 0;
}

/* BODY */
body {
  background-color: #f8f8f8 !important;
  -webkit-font-smoothing: antialiased;
}

#ajax-spinner {
    display: none !important;
}

h1 {
    font-family: 'Montserrat', sans-serif;
    font-weight: 400;
    color: #242424;
    line-height: 36px;
    text-transform: uppercase;
    font-size: 26px;
}

h2 {
    font-family: 'Montserrat', sans-serif;
    font-weight: 700;
    color: #242424;
    line-height: 36px;
    text-transform: uppercase;
    font-size: 1.125em;
    margin: 0 0;
}

h3 {
    font-family: 'Montserrat', sans-serif;
    font-weight: 700;
    color: #242424;
    line-height: 24px;
    text-transform: uppercase;
    font-size: 1.000em;
    margin: 0 0;
}

h4 {
    font-family: 'Montserrat', sans-serif;
    font-weight: 700;
    color: #242424;
    line-height: 21px;
    text-transform: uppercase;
    font-size: 0.875em;
    margin: 0 0;
}

p {
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    line-height: 33px;
    color: #666666;
}

ul {
    margin: 0 0 30px 25px;
}

ol {
    margin: 0 0 40px 25px;
}

.row {
    margin-left: 0px !important;
    margin-right: 0px !important;
}

.col-md-12 {
    padding-left: 0px !important;
    padding-right: 0px !important;
}

#edit-content-views {
    margin-top: 50px;
    width: 90%;
}

#content {
    clear: both;
}

#content table {
    width: 100%;
}

#content a {
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    font-size: 1.250em;
    color: #242424;
    line-height: 33px;
    text-decoration: underline;
}

#content a:visited {
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    font-size: 1.250em;
    color: #666666;
    line-height: 33px;
    text-decoration: underline;
}

#content th {
    background-color: #f8f8f8;
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    color: #666666;
    font-size: 1.125em;
}

#content tr {
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    color: #666666;
    font-size: 1.125em;
}

#content ul {
    margin-left: 20px;
}

#content ol {
    margin-left: 24px;
}

#content .pullquote {
    font-family: 'Lato', sans-serif;
    margin: 0 auto;
    font-weight: 300;
    width: auto;
    font-size: 1.875em;
    float: left;
    background: none;
    color: #666666;
    line-height: 45px;
    float: none !important;
    letter-spacing: 0.05em !important;
    border-left: 2px solid #cccccc;
    padding-left: 20px;
    padding-right: 20px;
    padding-top: 0px;
    padding-bottom: 5px;
    margin-bottom: 28px;
}

#content a:hover,
dl.portlet a:hover {
    color: #242424 !important; 
}

#portal-logo {
    width: 75px;
    height: 75px;
    margin-top: 50px;
    margin-left: 20px;
    margin-bottom: 0px;
}

#portal-logo img {
    width: 75px;
    height: 75px;
    margin-top: 50px;
    margin-left: 20px;
    margin-bottom: 0px;
    content: url('++resource++plonetheme.bootstrapModern.css/logo.png');
}

.section-intk #parent-fieldname-title {
    display: none;
}

#viewlet-below-content-body .managePortletsLink {
        display: none;
    }
}

/* LOGO */


#portal-logo img {
    width: 75px;
    height: 75px;
}

#content-core {
    background-color: #ffffff;
}

#parent-fieldname-title, .documentFirstHeading {
    font-size: 1.500em;
    text-transform: uppercase;
    color: #242424;
    font-family: 'Montserrat', sans-serif !important;
    line-height: 32px;
    font-weight: 700;
    margin: 0;
}

#content .documentDescription,
#content #description, .documentDescription {
    font-size: 1.250em;
    color: #999999;
    font-family: 'Lato', sans-serif !important;
    font-weight: 300;
    line-height: 26px;
}

.section-intk #content .documentDescription,
.section-intk #content #description, .documentDescription {
    font-size: 1.875em;
    color: #242424;
    font-family: 'Lato', sans-serif !important;
    font-weight: 300;
    line-height: 45px;
}

#parent-fieldname-description, .documentDescription {
    padding-bottom: 50px;
}

.section-intk #parent-fieldname-description {
    padding-bottom: 30px;
}

.section-intk #parent-fieldname-description {
    padding-top: 40px;
}

#content a:link {
    text-decoration: none;
}

#parent-fieldname-title, .documentFirstHeading {
    padding-left: 20px;
    padding-right: 20px;
    padding-top: 44px;
    margin-bottom: 7px;
}



#parent-fieldname-description, .documentDescription {
    padding-left: 20px;
    padding-right: 20px;
}

/* COLLECTION */
#content-core .tileColumns {
    padding-top: 50px;
}

#content-core .thumb-image img {
    width: 100%;
    display: block;
    margin: 0 auto;
}

#content-core .thumbnail {
    background-color: inherit;
    border: none;
    box-shadow: none;
    -webkit-box-shadow: none;
    margin-bottom: 45px;
    padding: 0px;
}

#content-core .caption {
    padding: 0px;
}

#content-core .thumbnail h3 {
    margin-top: 12px; /* margin from title to image */
    margin-bottom: 4px;
    text-transform: none;
    font-family: "Lato", sans-serif;
    font-weight: 300;
    font-color: #242424;
    font-size: 1.125em;
    line-height: 26px;
}

#content-core .thumbnail a {
    text-decoration: none;
    color: #242424;
    font-size: 1.250em;
    border-bottom: none;
}

#content-core .thumbnail a:hover {
    color: #242424;
}

#content-core .thumbnail a:focus {
    color: #242424;
}

#content-core .thumbnail a:active {
    color: #242424;
}

#content-core .thumbnail p {
    font-size: 1.125em;
    font-family: "Lato", sans-serif;
    color: #999999;
    line-height: 26px;
    font-weight: 300;
}


/* FOOTER */

#footer-manager-button {
    text-align: center;
}

#portal-footer-wrapper {
    padding-left: 0px;
    padding-right: 0px;
    padding-top: 50px;
    padding-bottom: 85px;
    background-color: #f8f8f8;
}

#FooterPortlet .portletWrapper:first-child {
    float:none;
    text-align: left;
    margin-top: 0px;
}

#FooterPortlet .portletWrapper {
    text-align: right;
}

#FooterPortlet .portletWrapper:first-child .portletStaticText {
    float:left;
}

#FooterPortlet .portletStaticText {
    float:right;
}

#FooterPortlet .portletWrapper p {
    font-family: 'Lato', sans-serif;
    font-size: 1.125em;
    color: #999999;
    line-height: 17px;
    font-weight: 300;
}

#FooterPortlet .portletWrapper p a {
    font-family: 'Lato', sans-serif;
    color: #999999;
    line-height: 17px;
    font-weight: 300;
    border-bottom: 0px;
}

#FooterPortlet .portletWrapper p a:hover {
    border-bottom: 1px solid #cccccc;
    text-decoration: none;
    -webkit-font-smoothing: antialiased;
}

#FooterPortlet .col-lg-2 h2 {
    font-family: 'Montserrat', sans-serif;
    text-transform: uppercase;
    font-size: 0.875em;
    color: #666666;
    margin: 4px 0px;
    margin-top: -6px;
    line-height: 26px;
    font-weight: 700;
}

#FooterPortlet .col-lg-6 h2 {
    font-family: 'Lato', sans-serif;
    font-size: 1.125em;
    color: #242424;
    line-height: 17px;
    font-weight: 300;
    margin-top: 0px;
    margin-bottom: 10px;
}

#FooterPortlet .col-lg-2:first-child {
    
}

/* FRONT-PAGE COLLECTION */

#content-core .portletCollection .portletHeader {
    text-align: center;
}

#content-core .portletCollection .portletHeader h1 {
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    text-transform: uppercase;
    font-size: 1.500em;
    color: #242424;
    margin: 0px;
    line-height: 35px;
}

#content-core .portletCollection .portletHeader h2 {
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    font-size: 1.250em;
    color: #999999;
    margin: 0px;
    line-height: 26px;
    margin-top: 5px;
    text-transform: none !important;
}

#content-core .portletCollection .portlet-gap {
    padding-top: 50px;
}

#content-core .portletCollection .portletFooter {
    text-align: center;
    padding-bottom: 100px;
}

#content-core .portletCollection .portletHeader {
    padding-top: 60px;
    padding-bottom: 55px;
}

#content-core .portletCollection {
    background-color: #ffffff;
}

#content-core .portletCollection .thumbnail {
    background-color: inherit;
}

#content-core .portletCollection .portletFooter .btn {
    background: #262626;
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    color: #ffffff;
    font-size: 0.875em;
    border-style: solid;
    border-width: 2px;
    border-color: #262626;
}

#content-core .portletCollection .portletFooter .btn:hover {
    background: #ffffff;
    border-style: solid;
    border-width: 2px;
    border-color: #242424;
    color: #262626 !important;
}

#content-core .portletCollection .portletFooter a:hover {
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    color: #ffffff !important;
    font-size: 0.875em;
}

#content-core .portletCollection .portletFooter a:focus {
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    color: #ffffff !important;
    font-size: 0.875em;
}

#content-core .portletCollection .portletFooter .btn-large {
    padding: 4px 18px;
}

/* NEWSLETTER */
#content-core .portletMailChimp .btn {
    background: #262626;
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    text-transform: uppercase;
    color: #ffffff;
    font-size: 0.875em;
    border-style: solid;
    border-width: 2px;
    border-color: #262626;
    padding: 8px 18px;
    -webkit-font-smoothing: antialiased;
}

#content-core .portletMailChimp .field {
    margin-bottom: 20px;
}

#content-core .portletMailChimp .btn:hover {
    background: #ffffff;
    border-style: solid;
    border-width: 2px;
    border-color: #242424;
    color: #262626 !important;
    padding: 8px 18px;
}

#content-core .portletMailChimp .formControls .btn {
    display: block;
    margin: 0 auto;
}

#formfield-form-widgets-email label {
    font-family: 'Lato', sans-serif;
    font-size: 1.250em;
    color: #999999;
    text-align: center;
    margin-bottom: 20px;
    font-weight: 300;
    width: 100%;
}

#formfield-form-widgets-email .help-block {
    display: none;
}

#formfield-form-widgets-email label .required {
    display: none;
}

#content-core .portletMailChimp .portletHeader {
    text-align: center;
    padding-top: 60px;
    padding-bottom: 10px;
}

#content-core .portletMailChimp .rowlike {
    margin: 0 0 100px;
}

#content-core .portletMailChimp .portletHeader h1 {
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    text-transform: uppercase;
    font-size: 1.500em;
    color: #242424;
    margin: 0px;
    line-height: 35px;
}

#content-core .portletMailChimp input {
    border: 0px;
    padding-left: 20px;
    padding-top: 10px;
    padding-bottom: 10px;
    padding-right: 20px;
    width: 68%;
    display: block;
    margin : 0 auto;
}

#formfield-form-widgets-interest_groups {
    display: none;
}

#content-core .portletMailChimp .formControls {
    margin: 0px;
}

#content-core .portletMailChimp .portletDescription {
    text-align: center;
    margin-top: -8px;
    margin-bottom: 20px;
}

#content-core .portletMailChimp .portletDescription p {
    color: #999999;
    font-size: 1.250em;
}

/* FRONT PAGE BUTTON */
.section-intk #portletPageTopRow > div:first-child .portlet-static a {
    background: #262626;
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    text-transform: uppercase;
    color: #ffffff;
    font-size: 0.875em;
    border-style: solid;
    border-width: 2px;
    border-color: #262626;
    padding: 4px 18px;
}

.section-intk #portletPageTopRow > div:first-child .portlet-static p {
    margin-bottom: 0px;
    padding-bottom: 100px;
}

.section-intk #portletPageTopRow > div:first-child .portlet-static a:hover {
    background: #ffffff;
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    text-transform: uppercase;
    color: #ffffff;
    font-size: 0.875em;
    border-style: solid;
    border-width: 2px;
    border-color: #262626;
}

.section-intk .get-in-contact {
    width: 180px;
    display: block;
    margin: 0 auto;
}

/* PORTLETS General */

#portletPageTopRow > div:first-child .portlet-static {
    background-color: #f8f8f8 !important;
}

#portletPageTopRow > div:nth-child(even) .portlet {
    background-color: #ffffff !important;
}

#portletPageTopRow > div:nth-child(even) .portletHeader {
    background-color: #ffffff !important;
}

#portletPageTopRow > div:nth-child(odd) .portlet {
    background-color: #f8f8f8 !important;
}

#portletPageTopRow > div:nth-child(odd) .portletHeader {
    background-color: #f8f8f8 !important;
}

/* SLIDESHOW */
.slideshowImage {
    padding-top: 50px;
    padding-left: 120px;
    padding-right: 120px;
}

.slideshowImage img {
    width: 100%;
}

/* OLD SLIDESHOW */

#slideshow {
    background-color: #ffffff;
}

.embededMediaShow, .mediaShowSlide {
    padding-top: 50px;
}

.embededMediaShow.javascripted .mediaShowSlide .mediaShowMedia {
    padding-top: 50px;
}

/* SINGLE PAGE CONTENT */

#content-core div[id*='parent-fieldname-text'], #content div[id*='parent-fieldname-formPrologue'], .pfg-form {
    padding-top: 50px;
    padding-left: 370px;
    padding-right: 370px;
    line-height: 30px;
    padding-bottom: 95px;
}

#content-core div[id*='parent-fieldname-text'] {
    color: #666666;
    font-size: 1.250em;
    font-family: 'Lato', sans-serif !important;
    font-weight: 300;
}

#content-core div[id*='parent-fieldname-text'] h2, #content div[id*='parent-fieldname-formPrologue'] h2, .pfg-form h2 {
    font-family: 'Montserrat', sans-serif !important;
    font-weight: 700;
    text-transform: uppercase;
    font-size: 1.125em;
    letter-spacing: 0.05em;
    margin-bottom: -5px;
}

#content-core div[id*='parent-fieldname-text'] h3, #content div[id*='parent-fieldname-formPrologue'] h3, .pfg-form h3 {
    letter-spacing: 0.05em;
}

#content-core div[id*='parent-fieldname-text'] h4, #content div[id*='parent-fieldname-formPrologue'] h4, .pfg-form h4 {
    letter-spacing: 0.05em;
}

#content-core div[id*='parent-fieldname-text'] p {
    margin-bottom: 30px;
}

/* EDITING TEMPLATES BACKEND */

.template-atct_edit #content {
    background-color: #ffffff;
    padding-left: 120px;
    padding-right: 120px;
    padding-bottom: 50px;
    padding-top: 50px;
    font-size: 0.875em;
    font-weight: 400;
}

.template-atct_edit #content ul li a {
    font-size: 0.875em;
}

.template-atct_edit #content p {
    font-size: 1em;
}

.template-atct_edit #content a {
    font-size: 0.875em;
}

.template-atct_edit #content #text_style_text a {
    font-size: 1em;
    line-height: 20px;
}

.template-atct_edit #content .previewresults {
    padding: 15px;
}

.template-atct_edit #content .formControls {
    margin: 0;
}

.template-atct_edit #content #archetypes-fieldname-title input {
    font-size: 1.000em;
}

.template-atct_edit #content #archetypes-fieldname-description textarea#description {
    font-size: 0.875em;
}

.template-atct_edit #content .discreet {
    font-size: 1.000em;
}

.template-atct_edit #content #search-results {
    font-size: 1.000em;
}

.template-atct_edit #content .formQuestion {
    font-size: 1.250em;
}

.template-atct_edit #content .formQuestion .help-block {
    font-size: 0.875em;
}

#editContentActionMenus {
    padding-left: 120px;
    padding-right: 120px;
}

/* folder contents */

.template-folder_contents #content a {
    font-size: 0.875em;
}

.template-folder_contents #content .documentDescription {
    padding-bottom: 50px !important;
}

.template-folder_contents #content table tr {
    font-size: 1.125em;
}

.template-folder_contents #content table td {
    font-size: 0.875em;
}

.template-folder_contents #content table th {
    font-size: 1.000em;
}

.template-folder_contents #content {
    font-size: 0.875em;
}

.template-folder_contents #content table {
    font-size: 0.875em;
}

.template-folder_contents .folder_contents_portlet_manager {
    font-size: 0.875em;
}

.template-folder_contents .link-parent {
    margin-left: -80px;
}

.template-folder_contents #content .managePortletsFallback {
    padding: 0px;
    margin: 0px;
    width: 100%;
    display: block;
    margin: 0 auto;
}

.template-folder_contents #content .row {
    margin-left: 0px;
    margin-right: 0px;
}

.template-croppingeditor #content {
    background-color: #ffffff;
    padding-left: 40px;
    padding-right: 40px;
    padding-bottom: 50px;
    padding-top: 50px;
    font-size: 1.000em;
}

.template-croppingeditor #content .row {
    margin-left: 0px;
    margin-right: 0px;
}


.template-croppingeditor #content .row > div {
    width: 70%;
    float:right;
}

.template-croppingeditor #content .row > div:first-child {
    width: 20%;
    float: left;
}

/* Manage portlets page */
.pagePortletDiv .managePortletsLink {
    display: none;
}

.pagePortletDiv .container-fluid {
    padding-top: 0px !important;
}

.pagePortletDiv .portlet-gap {
    display: none;
}

.pagePortletDiv {
    margin-top: -5px;
    padding-bottom: 40px;
}

.pagePortletDiv .managePortletsFallback {
    font-size: 0.875em !important;
}

.pagePortletDiv .managePortletsFallback {
    width: 30%;
}

.pagePortletDiv .thumbnail a {
    font-size: 1.125em !important;
}

/* CONTACT PAGE */

#content div[id*='parent-fieldname-formPrologue'] {
    background-color: #ffffff;
}

#content div[id*='parent-fieldname-formPrologue'] {
    padding-bottom: 35px !important;
}

#content .pfg-form {
    background-color: #ffffff;
}

#content .pfg-form {
    padding-top: 0px !important;
}

#content .pfg-form .field input[type="text"] {
    width: 100% !important;
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    font-size: 1.125em;
    color: #999999;
    background-color: #f8f8f8;
    border: 0;
    -webkit-box-shadow: none;
    box-shadow: none;
}

#content .pfg-form .required {
    display: none;
}

#content .pfg-form .formQuestion {
    text-transform: uppercase;
    font-family: 'Montserrat', sans-serif;
    font-weight: 700;
    font-size: 1em;
    margin-bottom: 0;
}

#content .pfg-form .formControls {
    margin-left: 0;
}

#content .pfg-form textarea {
    font-family: 'Lato', sans-serif;
    font-weight: 300;
    font-size: 1.125em;
    color: #999999;
    background-color: #f8f8f8;
    border: 0;
    -webkit-box-shadow: none;
    box-shadow: none;
}

#content div[id*='parent-fieldname-formPrologue'] p {
    font-size: 1.125em;
}

#content div[id*='parent-fieldname-formPrologue'] h3 {
    margin-top: 35px !important;
}

#content div[id*='parent-fieldname-formPrologue'] h3 ~ p {
    margin-bottom: 0px;
}

#content .pfg-form .formControls .btn {
    background: #262626;
    font-family: "Montserrat", sans-serif;
    font-weight: 400;
    color: #ffffff;
    font-size: 0.875em;
    border-style: solid;
    border-width: 2px;
    border-color: #262626;
    text-transform: uppercase;
}

#content .pfg-form .formControls .btn:hover {
    background: #ffffff;
    border-style: solid;
    border-width: 2px;
    border-color: #242424;
    color: #262626 !important;
}



/* TEMPORARY */
#content-core .portletMailChimp #formfield-form-widgets-email label {
    display: none;
}

/* MEDIA QUERIES */
@media (max-width: 480px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }
}

/* TABLET */
@media (min-width: 481px) and (max-width: 767px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }
    #portal-columns {
        padding-left: 0px;
        padding-right: 0px;
    }
}
@media (min-width: 768px) and (max-width: 991px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }

    #portal-columns {
        padding-left: 0px;
        padding-right: 0px;
    }
}

/* DEFAULT */
@media (min-width: 992px) and (max-width: 1199px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }
    #portal-columns {
        padding-left: 0px;
        padding-right: 0px;
    }
}
@media (min-width: 1200px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }
    #portal-columns {
        padding-left: 0px;
        padding-right: 0px;
    }
}


@media (max-width: 480px) {
    #parent-fieldname-title, .documentFirstHeading {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 481px) and (max-width: 767px) {
    #parent-fieldname-title, .documentFirstHeading {
        padding-left: 40px;
        padding-right: 40px;
    }
}

/* TABLET */
@media (min-width: 768px) and (max-width: 991px) {
    #parent-fieldname-title, .documentFirstHeading {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #parent-fieldname-title, .documentFirstHeading {
        padding-left: 120px;
        padding-right: 120px;
    }
}

@media (min-width: 1200px) {
    #parent-fieldname-title, .documentFirstHeading {
        padding-left: 120px;
        padding-right: 120px;
    }
}

/* Media logo */
@media (max-width: 480px) {
    #portal-logo img {
        margin-top: 25px;
        margin-left: 0px;  
    }
}

@media (min-width: 481px) and (max-width: 767px) {
    #portal-logo img {
        margin-top: 30px;
        margin-left: 20px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    #portal-logo img {
        margin-top: 30px;
        margin-left: 20px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #portal-logo img {
        margin-top: 50px;
        margin-left: 30px;
    }
}

@media (min-width: 1200px) {
    #portal-logo img {
        margin-top: 50px;
        margin-left: 30px;
    }
}



@media (max-width: 480px) {
    #parent-fieldname-description {
        padding-left: 20px;
        padding-right: 20px;
    }

    .documentDescription {
        padding-left: 20px;
        padding-right: 20px;
    }

    .section-intk #content .documentDescription, .section-intk #content #description {
        font-size: 1.500em;
        line-height: 37px;
    }

    .section-intk #parent-fieldname-description {
        padding-top: 40px;
    }
}

/* TABLET */
@media (min-width: 481px) and (max-width: 767px) {
    #parent-fieldname-description {
        padding-left: 40px;
        padding-right: 40px;
    }

    .documentDescription {
        padding-left: 40px;
        padding-right: 40px;
    }

    .section-intk #parent-fieldname-description {
        padding-right: 75px;
    }

    .section-intk #parent-fieldname-description {
        padding-top: 40px;
    }
}

/* DEFAULT */
@media (min-width: 768px) and (max-width: 991px) {
    #parent-fieldname-description, .documentDescription {
        padding-left: 40px;
        padding-right: 40px;
    }

    .section-intk #parent-fieldname-description {
        padding-left: 40px;
        padding-right: 40px;
    }

    .section-intk #parent-fieldname-description {
        padding-top: 90px;
        padding-bottom: 30px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #parent-fieldname-description {
        padding-left: 120px;
        padding-right: 120px;
    }

    .section-intk #parent-fieldname-description {
        padding-left: 0px;
        padding-right: 0px;
        width: 850px;
        display: block;
        margin: 0 auto;
    }

    .section-intk #parent-fieldname-description {
        padding-top: 90px;
        padding-bottom: 30px;
    }
}

@media (min-width: 1200px) {
    #parent-fieldname-description, .documentDescription {
        padding-left: 120px;
        padding-right: 120px;
    }

    .section-intk #parent-fieldname-description {
        padding-left: 0px;
        padding-right: 0px;
        width: 850px;
        display: block;
        margin: 0 auto;
    }

    .section-intk #parent-fieldname-description {
        padding-top: 90px;
        padding-bottom: 30px;
    }
}



/* Override media queries */
@media (max-width: 480px) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription {
        text-align: left;
    }
}

/* TABLET */

@media (min-width: 481px) and (max-width: 767px) {
    body {
        padding-left: 0px;
        padding-right: 0px;
    }

    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription, .documentFirstHeading {
        text-align: left;
    }
}

/* DEFAULT */

@media (min-width: 768px) and (max-width: 979) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription, .documentFirstHeading {
        text-align: left;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription, .documentFirstHeading {
        text-align: center;
    }
}

@media (min-width: 1200px) {
    #portal-columns {
        padding-left: 0px !important;
        padding-right: 0px !important;
    }

    #parent-fieldname-title, #content .documentDescription, .documentFirstHeading {
        text-align: center;
    }
}

/* tile columns */
@media (max-width: 480px) {
    #content-core .tileColumns {
        padding-left: 5px;
        padding-right: 5px;
    }
}

/* TABLET */
@media (min-width: 481px) and (max-width: 767px) {
    #content-core .tileColumns {
        padding-left: 25px;
        padding-right: 25px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    #content-core .tileColumns {
        padding-left: 25px;
        padding-right: 25px;
    }
}

/* DEFAULT */
@media (min-width: 992px) and (max-width: 1199px) {
    #content-core .tileColumns {
        padding-left: 25px;
        padding-right: 25px;
    }
}

@media (min-width: 1200px) {
    #content-core .tileColumns {
        padding-left: 100px;
        padding-right: 100px;
    }
}

/* Footer */

@media (max-width: 480px) {
    #FooterPortlet {
        padding-left: 0px;
        padding-right: 0px;
    }

    #FooterPortlet .portletWrapper:first-child {
        text-align: left;
    }
    #FooterPortlet .portletWrapper .portletStaticText {
        text-align: left;
        margin-bottom: 18px;
    }

    #FooterPortlet .col-lg-2:first-child {
        margin-left: 0px;
    }

    #FooterPortlet .portletStaticText {
        text-align: left;
    }
}

/* TABLET */
@media (min-width: 481px) and (max-width: 767px) {
    #FooterPortlet {
        padding-left: 20px;
        padding-right: 20px;
    }

    #FooterPortlet .portletStaticText {
        text-align: left;
    }

    #FooterPortlet .portletWrapper .portletStaticText {
        text-align: left;
        margin-bottom: 18px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    #FooterPortlet {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #FooterPortlet {
        padding-left: 100px;
        padding-right: 100px;
    }
}

@media (min-width: 1200px) {
    #FooterPortlet {
        padding-left: 100px;
        padding-right: 100px;
    }
}

@media (max-width: 480px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 20px;
        padding-right: 20px;
    }

    #content-core #row-items {
        padding-left: 5px;
        padding-right: 5px;
    }

    #content-core .portletMailChimp .rowlike {
        margin: 0 0 70px !important;
    }
}

@media (min-width: 481px) and (max-width: 767px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
    }

    #content-core #row-items {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
    }

    #content-core #row-items {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
    }

    #content-core #row-items {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 1200px) {
    #content-core .portletCollection .container-fluid {
        padding-left: 120px;
        padding-right: 120px;
    }

    #content-core #row-items {
        padding-left: 100px;
        padding-right: 100px;
    }
}


@media (max-width: 480px) {
    #content-core .portletMailChimp .formControls .btn {
        display: block;
        margin: 0;
    }
    #content-core .portletMailChimp .container-fluid {
        padding-left: 20px;
        padding-right: 20px;
    }
}


@media (min-width: 481px) and (max-width: 767px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
    }

    #content-core .portletMailChimp .formControls .btn {
        display: block;
        margin: 0;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 40px;
        padding-right: 40px;
        text-align: center;
    }
    #formfield-form-widgets-email label {
        text-align: center;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 120px;
        padding-right: 120px;
    }
}

@media (min-width: 1200px) {
    #content-core .portletMailChimp .container-fluid {
        padding-left: 120px;
        padding-right: 120px;
    }
}

@media (max-width: 480px) {
    .section-intk #portletPageTopRow > div:first-child .portlet-static p {
        margin-bottom: 0px;
        padding-bottom: 50px;
    }

    .section-intk .get-in-contact {
        margin: 0;
        margin-left: 20px;
    }
}

@media (min-width: 481px) and (max-width: 767px) {
    .section-intk #portletPageTopRow > div:first-child .portlet-static p {
        margin-bottom: 0px;
        padding-bottom: 50px;
    }

    .section-intk .get-in-contact {
        margin: 0;
        margin-left: 40px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .section-intk #portletPageTopRow > div:first-child .portlet-static p {
        margin-bottom: 0px;
        padding-bottom: 50px;
    }

    .section-intk .get-in-contact {
        margin: 0;
        margin-left: 40px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .section-intk #portletPageTopRow > div:first-child .portlet-static p {
        margin-bottom: 0px;
        padding-bottom: 100px;
    }

    .section-intk .get-in-contact {
        margin: 0 auto;
    }
}

@media (min-width: 1200px) {
    .section-intk #portletPageTopRow > div:first-child .portlet-static p {
        margin-bottom: 0px;
        padding-bottom: 100px;
    }

    .section-intk .get-in-contact {
        margin: 0 auto;
    }
}

/* PORTLETS */

@media (max-width: 480px) {

    .slideshowImage {
        padding-top: 0px;
        padding-left: 0px;
        padding-right: 0px;
    }

    .portletHeader {
        text-align: left !important;
    }

    #formfield-form-widgets-email label {
        text-align: left !important;
    }

    #content-core .portletMailChimp input {
        width: 100%;
        padding-left: 5%;
        padding-right: 0px;
        margin-left: 0px;
    }
}

@media (min-width: 481px) and (max-width: 767px) {
    .slideshowImage {
        padding-top: 0px;
        padding-left: 0px;
        padding-right: 0px;
    }

    .portletHeader {
        text-align: left !important;
    }

    #formfield-form-widgets-email label {
        text-align: left !important;
    }

    #content-core .portletMailChimp input {
        width: 100%;
        padding-left: 5%;
        padding-right: 0px;
        margin-left: 0px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .slideshowImage {
        padding-top: 0px;
        padding-left: 0px;
        padding-right: 0px;
    }

    #formfield-form-widgets-email label {
        text-align: center !important;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .slideshowImage {
        padding-top: 0px;
        padding-left: 0px;
        padding-right: 0px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .slideshowImage {
        padding-top: 50px;
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    .slideshowImage {
        padding-top: 50px;
        padding-left: 120px;
        padding-right: 120px;
    }
}




@media (max-width: 480px) {
    .embededMediaShow.javascripted .mediaShowSlide .mediaShowMedia {
        padding-top: 0px;
    }

    #content-core div[id*='parent-fieldname-text'], #content div[id*='parent-fieldname-formPrologue'], .pfg-form {
        padding-left: 20px;
        padding-right: 20px;
        line-height: 30px;
        padding-bottom: 35px;
        font-size: 1.125em;
    }
}

@media (min-width: 481px) and (max-width: 767px) {
    .embededMediaShow.javascripted .mediaShowSlide .mediaShowMedia {
        padding-top: 0px;
    }

    #content-core div[id*='parent-fieldname-text'], #content div[id*='parent-fieldname-formPrologue'], .pfg-form {
        padding-left: 40px;
        padding-right: 40px;
        line-height: 30px;
        padding-bottom: 35px;
    }
}

@media (min-width: 768px) and (max-width: 991px) {
    .embededMediaShow.javascripted .mediaShowSlide .mediaShowMedia {
        padding-top: 0px;
    }

    #content-core div[id*='parent-fieldname-text'], #content div[id*='parent-fieldname-formPrologue'], .pfg-form {
        padding-left: 40px;
        padding-right: 40px;
        line-height: 30px;
        padding-bottom: 35px;
    }
}

@media (min-width: 992px) and (max-width: 1199px) {
    .embededMediaShow.javascripted .mediaShowSlide .mediaShowMedia {
        padding-top: 50px;
    }

    #content-core div[id*='parent-fieldname-text'], #content div[id*='parent-fieldname-formPrologue'], .pfg-form {
        padding-top: 50px;
        padding-left: 26%;
        padding-right: 26%;
        line-height: 30px;
        padding-bottom: 65px;
    }
}

@media (min-width: 1200px) {
    .embededMediaShow.javascripted .mediaShowSlide .mediaShowMedia {
        padding-top: 50px;
    }

    #content-core div[id*='parent-fieldname-text'], #content div[id*='parent-fieldname-formPrologue'], .pfg-form {
        padding-top: 50px;
        padding-left: 26%;
        padding-right: 26%;
        line-height: 30px;
        padding-bottom: 65px;
    }
}


/* BACK END QUERIES */

@media (max-width: 991px) and (min-width: 768px) {
    .template-atct_edit #content {
        background-color: #ffffff;
        padding-left: 40px;
        padding-right: 40px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-croppingeditor #content {
        background-color: #ffffff;
        padding-left: 40px;
        padding-right: 40px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-folder_contents #content {
        background-color: #ffffff;
        padding-left: 40px;
        padding-right: 40px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    #editContentActionMenus {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (max-width: 500px) {
    .template-folder_contents .link-parent {
        margin-left: 0px;
    }
}

@media (max-width: 767px) {
    .template-atct_edit #content {
        background-color: #ffffff;
        padding-left: 20px;
        padding-right: 20px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-croppingeditor #content {
        background-color: #ffffff;
        padding-left: 20px;
        padding-right: 20px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-folder_contents #content {
        background-color: #ffffff;
        padding-left: 20px;
        padding-right: 20px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    #editContentActionMenus {
        padding-left: 20px;
        padding-right: 20px;
    }
}

@media (min-width: 992px) {
    .template-atct_edit #content {
        background-color: #ffffff;
        padding-left: 40px;
        padding-right: 40px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-croppingeditor #content {
        background-color: #ffffff;
        padding-left: 40px;
        padding-right: 40px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-folder_contents #content {
        background-color: #ffffff;
        padding-left: 40px;
        padding-right: 40px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    #editContentActionMenus {
        padding-left: 40px;
        padding-right: 40px;
    }
}

@media (min-width: 1200px) {
    .template-atct_edit #content {
        background-color: #ffffff;
        padding-left: 120px;
        padding-right: 120px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 0.875em;
    }

    .template-folder_contents #content {
        background-color: #ffffff;
        padding-left: 120px;
        padding-right: 120px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    .template-croppingeditor #content {
        background-color: #ffffff;
        padding-left: 120px;
        padding-right: 120px;
        padding-bottom: 50px;
        padding-top: 50px;
        font-size: 1.000em;
    }

    #editContentActionMenus {
        padding-left: 120px;
        padding-right: 120px;
    }
}













